@@ -48,9 +48,9 @@ Catmandu::Fix::marc_add - add new fields to marc
 
 =head1 SYNOPSIS
 
-    marc_add('900', a, 'test' , 'b', test);
-    marc_add('900', ind1 , ' ' , a, 'test' , 'b', test);
-    marc_add('900', ind1 , ' ' , a, 'test' , 'b', test , -record => 'record2');
+    marc_add('900', a, 'test' , 'b', test)
+    marc_add('900', ind1 , ' ' , a, 'test' , 'b', test)
+    marc_add('900', ind1 , ' ' , a, 'test' , 'b', test , -record => 'record2')
 
 =head1 SEE ALSO
 
